#[repr(C)]pub struct DateFormat {
pub era_number: i32,
pub era_offset: u32,
pub fraction: u64,
}Expand description
NTP Date Format - The prime epoch, or base date of era 0, is 0 h 1 January 1900 UTC, when all bits are zero. Dates are relative to the prime epoch; values greater than zero represent times after that date; values less than zero represent times before it.
Note that the era_offset field has the same interpretation as the seconds field of the
TimestampFormat type.
ⓘ
0 1 2 3
0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Era Number |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Era Offset |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| |
| Fraction |
| |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+Fields
era_number: i32era_offset: u32fraction: u64Trait Implementations
Sourceimpl Clone for DateFormat
impl Clone for DateFormat
Sourcefn clone(&self) -> DateFormat
fn clone(&self) -> DateFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstPackedSizeBytes for DateFormat
impl ConstPackedSizeBytes for DateFormat
const PACKED_SIZE_BYTES: usize = 16
Sourceimpl Debug for DateFormat
impl Debug for DateFormat
Sourceimpl Default for DateFormat
impl Default for DateFormat
Sourcefn default() -> DateFormat
fn default() -> DateFormat
Returns the “default value” for a type. Read more
Sourceimpl Hash for DateFormat
impl Hash for DateFormat
Sourceimpl Ord for DateFormat
impl Ord for DateFormat
Sourcefn cmp(&self, other: &DateFormat) -> Ordering
fn cmp(&self, other: &DateFormat) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DateFormat
impl PartialEq for DateFormat
Sourceimpl PartialOrd for DateFormat
impl PartialOrd for DateFormat
Sourceimpl ReadFromBytes for DateFormat
impl ReadFromBytes for DateFormat
Sourcefn read_from_bytes<R: ReadBytesExt>(reader: R) -> Result<Self>
fn read_from_bytes<R: ReadBytesExt>(reader: R) -> Result<Self>
Read the command from bytes.
Sourceimpl WriteToBytes for DateFormat
impl WriteToBytes for DateFormat
Sourcefn write_to_bytes<W: WriteBytesExt>(&self, writer: W) -> Result<()>
fn write_to_bytes<W: WriteBytesExt>(&self, writer: W) -> Result<()>
Write the command to bytes.
impl Copy for DateFormat
impl Eq for DateFormat
impl StructuralPartialEq for DateFormat