#[repr(C)]pub struct ShortFormat {
pub seconds: u16,
pub fraction: u16,
}Expand description
NTP Short Format - Used in delay and dispersion header fields where the full resolution and range of the other formats are not justified. It includes a 16-bit unsigned seconds field and a 16-bit fraction field.
Layout
ⓘ
0 1 2 3
0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 0 1
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
| Seconds | Fraction |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+Fields
seconds: u16fraction: u16Trait Implementations
Sourceimpl Clone for ShortFormat
impl Clone for ShortFormat
Sourcefn clone(&self) -> ShortFormat
fn clone(&self) -> ShortFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ConstPackedSizeBytes for ShortFormat
impl ConstPackedSizeBytes for ShortFormat
const PACKED_SIZE_BYTES: usize = 4
Sourceimpl Debug for ShortFormat
impl Debug for ShortFormat
Sourceimpl Default for ShortFormat
impl Default for ShortFormat
Sourcefn default() -> ShortFormat
fn default() -> ShortFormat
Returns the “default value” for a type. Read more
Sourceimpl From<Instant> for ShortFormat
impl From<Instant> for ShortFormat
Sourceimpl From<ShortFormat> for Instant
impl From<ShortFormat> for Instant
Sourcefn from(t: ShortFormat) -> Self
fn from(t: ShortFormat) -> Self
Converts to this type from the input type.
Sourceimpl Hash for ShortFormat
impl Hash for ShortFormat
Sourceimpl Ord for ShortFormat
impl Ord for ShortFormat
Sourcefn cmp(&self, other: &ShortFormat) -> Ordering
fn cmp(&self, other: &ShortFormat) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ShortFormat
impl PartialEq for ShortFormat
Sourceimpl PartialOrd for ShortFormat
impl PartialOrd for ShortFormat
Sourceimpl ReadFromBytes for ShortFormat
impl ReadFromBytes for ShortFormat
Sourcefn read_from_bytes<R: ReadBytesExt>(reader: R) -> Result<Self>
fn read_from_bytes<R: ReadBytesExt>(reader: R) -> Result<Self>
Read the command from bytes.
Sourceimpl WriteToBytes for ShortFormat
impl WriteToBytes for ShortFormat
Sourcefn write_to_bytes<W: WriteBytesExt>(&self, writer: W) -> Result<()>
fn write_to_bytes<W: WriteBytesExt>(&self, writer: W) -> Result<()>
Write the command to bytes.
impl Copy for ShortFormat
impl Eq for ShortFormat
impl StructuralPartialEq for ShortFormat