#[repr(u32)]pub enum ReferenceIdentifier {
PrimarySource(PrimarySource),
SecondaryOrClient([u8; 4]),
KissOfDeath(KissOfDeath),
}Expand description
A 32-bit code identifying the particular server or reference clock.
The interpretation depends on the value in the stratum field:
- For packet stratum 0 (unspecified or invalid), this is a four-character ASCII [RFC1345] string, called the “kiss code”, used for debugging and monitoring purposes.
- For stratum 1 (reference clock), this is a four-octet, left-justified, zero-padded ASCII string assigned to the reference clock.
The authoritative list of Reference Identifiers is maintained by IANA; however, any string beginning with the ASCII character “X” is reserved for unregistered experimentation and development.
Variants
PrimarySource(PrimarySource)
SecondaryOrClient([u8; 4])
The reference identifier of the secondary or client server. Can be used to detect timing loops.
If using the IPv4 address family, the identifier is the four-octet IPv4 address.
If using the IPv6 address family, it is the first four octets of the MD5 hash of the IPv6 address. Note that when using the IPv6 address family on a NTPv4 server with a NTPv3 client, the Reference Identifier field appears to be a random value and a timing loop might not be detected.
KissOfDeath(KissOfDeath)